==> openGion7.0.5.0_dev.zip: uap/webapps/ge/db/SQLSERVER/sql/install/01_TABLE/GE80S.sql <==
/****************************************************************************/
/* GE80 ( FAQﾃｰﾌﾞﾙ )                                                        */
/*                                                                          */
/* Created : 2018/09/28 16:03:40                                            */
/****************************************************************************/

CREATE TABLE GE80 (
   SYSTEM_ID    varchar           (   10 )                  NOT NULL            /*  10 ｼｽﾃﾑID       */
 , SYSCODE      varchar           (   20 )      DEFAULT '*' NOT NULL            /*  20 ｼｽﾃﾑｺｰﾄﾞ     */
 , KBFAQ        varchar           (    1 )      DEFAULT '0' NOT NULL            /*  30 FAQ区分      */
 , QANO         varchar           (   20 )                  NOT NULL            /*  40 質問番号     */
 , CDBNRUI      varchar           (   10 )                                      /*  50 分類ｺｰﾄﾞ     */
 , KNRNGUI      varchar           (  200 )                                      /*  60 関連画面ID   */
 , TITLE        varchar           (  300 )                                      /*  70 ﾀｲﾄﾙ         */
 , NAIYO        varchar           ( 4000 )                                      /*  80 内容         */
 , SEQNO        INTEGER                         DEFAULT 0   NOT NULL            /*  90 表示順       */
 , FILE1        varchar           (  200 )                                      /* 100 ﾌｧｲﾙ1        */
 , FILE2        varchar           (  200 )                                      /* 110 ﾌｧｲﾙ2        */
 , FILE3        varchar           (  200 )                                      /* 120 ﾌｧｲﾙ3        */
 , FILEPATH     varchar           (  200 )                                      /* 130 ﾌｧｲﾙﾊﾟｽ      */
 , TAG          varchar           (  200 )                                      /* 140 ﾀｸﾞｷｰﾜｰﾄﾞ    */
 , UNIQ         int IDENTITY(1,1)                                               /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          varchar           (    1 )      DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        varchar           (   14 )                                      /* 820 登録日時     */
 , PGSET        varchar           (   10 )                                      /* 830 作成PG       */
 , PGPSET       varchar           (   10 )                                      /* 840 作成親PG     */
 , USRSET       varchar           (   10 )                                      /* 850 作成者       */
 , DYUPD        varchar           (   14 )                                      /* 860 更新日時     */
 , PGUPD        varchar           (   10 )                                      /* 870 更新PG       */
 , PGPUPD       varchar           (   10 )                                      /* 880 更新親PG     */
 , USRUPD       varchar           (   10 )                                      /* 890 更新者       */
);

==> openGion7.3.0.1_dev.zip: uap/webapps/ge/db/SQLSERVER/sql/install/01_TABLE/GE80S.sql <==
/****************************************************************************/
/* GE80 ( FAQﾃｰﾌﾞﾙ )                                                        */
/*                                                                          */
/* Created : 2020/12/16 08:14:20                                            */
/****************************************************************************/

CREATE TABLE GE80 (
   SYSTEM_ID    varchar           (   10 )                  NOT NULL            /*  10 ｼｽﾃﾑID       */
 , SYSCODE      varchar           (   20 )      DEFAULT '*' NOT NULL            /*  20 ｼｽﾃﾑｺｰﾄﾞ     */
 , KBFAQ        varchar           (    1 )      DEFAULT '0' NOT NULL            /*  30 FAQ区分      */
 , QANO         varchar           (   20 )                  NOT NULL            /*  40 質問番号     */
 , CDBNRUI      varchar           (   10 )                                      /*  50 分類ｺｰﾄﾞ     */
 , KNRNGUI      varchar           (  200 )                                      /*  60 関連画面ID   */
 , TITLE        varchar           (  300 )                                      /*  70 ﾀｲﾄﾙ         */
 , NAIYO        varchar           ( 4000 )                                      /*  80 内容         */
 , SEQNO        INTEGER                         DEFAULT 0   NOT NULL            /*  90 表示順       */
 , FILE1        varchar           (  200 )                                      /* 100 ﾌｧｲﾙ1        */
 , FILE2        varchar           (  200 )                                      /* 110 ﾌｧｲﾙ2        */
 , FILE3        varchar           (  200 )                                      /* 120 ﾌｧｲﾙ3        */
 , FILEPATH     varchar           (  200 )                                      /* 130 ﾌｧｲﾙﾊﾟｽ      */
 , TAG          varchar           (  200 )                                      /* 140 ﾀｸﾞｷｰﾜｰﾄﾞ    */
 , UNIQ         int IDENTITY(1,1)                                               /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          varchar           (    1 )      DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        varchar           (   14 )                                      /* 820 作成日時     */
 , PGSET        varchar           (   10 )                                      /* 830 作成PG       */
 , PGPSET       varchar           (   10 )                                      /* 840 作成親PG     */
 , USRSET       varchar           (   10 )                                      /* 850 作成者       */
 , DYUPD        varchar           (   14 )                                      /* 860 更新日時     */
 , PGUPD        varchar           (   10 )                                      /* 870 更新PG       */
 , PGPUPD       varchar           (   10 )                                      /* 880 更新親PG     */
 , USRUPD       varchar           (   10 )                                      /* 890 更新者       */
);
